@@ -14,17 +14,17 @@ pub fn unimplemented(mut args: Args) -> Result<Val, Error> {
 }
 
 mod text;
+mod io;
 mod ipv4;
 mod dns;
-
-use text::TEXT;
-use ipv4::IPV4;
-use dns::DNS;
+mod tls;
 
 const STDLIB: phf::Map<&'static str, Symbol> = phf_map! {
-    "text" => Symbol::Module(&TEXT),
-    "ipv4" => Symbol::Module(&IPV4),
-    "dns" => Symbol::Module(&DNS),
+    "text" => Symbol::Module(&text::MODULE),
+    "io" => Symbol::Module(&io::MODULE),
+    "ipv4" => Symbol::Module(&ipv4::IPV4),
+    "dns" => Symbol::Module(&dns::DNS),
+    "tls" => Symbol::Module(&tls::TLS),
 };
 
 pub fn toplevel_module(name: &str) -> Option<&'static Module> {
